Class: OnyxCord::Webhooks::View::SelectMenuBuilder

Inherits:
Object
  • Object
show all
Defined in:
lib/onyxcord/webhooks/view.rb

Overview

A builder to assist in adding options to select menus.

Instance Method Summary collapse

Instance Method Details

#option(label:, value:, description: nil, emoji: nil, default: nil) ⇒ Object

Add an option to this select menu.

Parameters:

  • label (String)

    The title of this option.

  • value (String)

    The value that this option represents.

  • description (String, nil) (defaults to: nil)

    An optional description of the option.

  • emoji (#to_h, String, Integer) (defaults to: nil)

    An emoji ID, or unicode emoji to attach to the button. Can also be an object that responds to ‘#to_h` which returns a hash in the format of `{ id: Integer, name: string }`.

  • default (true, false, nil) (defaults to: nil)

    Whether this is the default selected option.



192
193
194
195
196
197
198
199
200
201
# File 'lib/onyxcord/webhooks/view.rb', line 192

def option(label:, value:, description: nil, emoji: nil, default: nil)
  emoji = case emoji
          when Integer, String
            emoji.to_i.positive? ? { id: emoji } : { name: emoji }
          else
            emoji&.to_h
          end

  @options << { label: label, value: value, description: description, emoji: emoji, default: default }
end